PurposeConditionalApplyState

Enum PurposeConditionalApplyState 

pub enum PurposeConditionalApplyState {
    Applied,
    Stale,
    Accepted,
    PathUnavailable,
}
Result of applying a purpose through the stale-safe curator path.

Variants



Applied

The current unapproved row matched and was approved atomically.



Stale

Project, generation, task, path, or purpose row state changed after selection.



Accepted

The path now has accepted authored intent and was not overwritten.



PathUnavailable

The selected path is no longer active in the current index.