RepositoryGraphRelationQuery

Enum RepositoryGraphRelationQuery 

pub enum RepositoryGraphRelationQuery {
    Outbound {
        source: GraphEntityKey,
    },
    Inbound {
        target: GraphEntityKey,
    },
    Family {
        relation: GraphRelationKind,
    },
}
Closed relation lookup shapes owned by normalized graph storage.

Variants



Outbound

Relations whose source is one exact stable entity.

Fields

source: GraphEntityKey

Exact project-qualified source key.



Inbound

Relations whose resolved or external target is one exact stable entity.

Fields

target: GraphEntityKey

Exact project-qualified target key.



Family

Relations in one typed legacy or extended family.

Fields

relation: GraphRelationKind

Exact relation family.