pub enum WorktreeUsageSyncState {
Synchronized,
Current,
}Expand description
Result of one monotonic worktree aggregate synchronization attempt.
Variants
Synchronized
A strictly newer snapshot replaced only the selected origin.
Current
The same or an older snapshot left the accepted origin unchanged.