database_settings_report

Function database_settings_report 

pub fn database_settings_report(path: &Path) -> DbResult<DatabaseSettingsReport>
Build bounded content-free database settings without creating, migrating, or repairing state.

Errors

Returns an error when runtime introspection or an otherwise admitted database read fails.