pub struct DatabaseOperatingProfileReport {
pub required_journal_mode: String,
pub observed_journal_mode: Option<String>,
pub required_synchronous_mode: String,
pub observed_synchronous_mode: Option<String>,
pub required_busy_timeout_ms: u64,
pub observed_busy_timeout_ms: Option<u64>,
pub checkpoint_write_interval: usize,
pub checkpoint_state: Option<TelemetryCheckpointState>,
pub wal_autocheckpoint_pages: Option<usize>,
pub statistics_policy: PlannerStatisticsPolicy,
pub statistics_state: Option<PlannerStatisticsState>,
}Expand description
Required and observed database connection and maintenance policy.
Fields
required_journal_mode: StringJournal mode required for live project databases.
observed_journal_mode: Option<String>Journal mode observed on the reporting connection, when available.
required_synchronous_mode: StringSynchronous mode required for authored and derived state.
observed_synchronous_mode: Option<String>Synchronous mode observed on the reporting connection, when available.
required_busy_timeout_ms: u64Busy timeout required for ordinary connections in milliseconds.
observed_busy_timeout_ms: Option<u64>Busy timeout observed on the reporting connection in milliseconds.
checkpoint_write_interval: usizeWrites between ProjectAtlas passive-checkpoint attempts.
checkpoint_state: Option<TelemetryCheckpointState>Most recent passive-checkpoint state, when durable state is available.
wal_autocheckpoint_pages: Option<usize>Connection-local automatic checkpoint threshold, when available.
statistics_policy: PlannerStatisticsPolicyProjectAtlas planner-statistics maintenance policy.
statistics_state: Option<PlannerStatisticsState>Observed planner-statistics state, when available.