pub struct HealthFindingsPage {
pub total: usize,
pub unfiltered_total: usize,
pub returned: usize,
pub start_index: usize,
pub limit: usize,
pub findings: Vec<HealthFinding>,
}Expand description
Bounded health findings page returned by the database layer.
Fields
total: usizeFindings after filters are applied.
unfiltered_total: usizeFindings before filters are applied, after resolved findings are removed.
returned: usizeFindings returned in this page.
start_index: usizePagination start index used for this page.
limit: usizeMaximum findings requested for this page.
findings: Vec<HealthFinding>Returned health finding rows.