pub struct PurposeCurationCandidate {
pub node: IndexedNode,
pub work_key: String,
pub state_token: String,
}Expand description
One unapproved purpose row bound to deterministic curator work.
Fields
node: IndexedNodeCurrent indexed node, purpose, and summary state.
work_key: StringProject/generation/task/path work identity used to coalesce duplicate work.
state_token: StringOpaque token binding conditional apply to this exact unapproved purpose row.