pub struct RepositoryGraphReadPage<T> {
pub page: RepositoryGraphPage<T>,
pub work: RepositoryGraphReadWork,
}Expand description
One stable paged graph result plus exact database work for the page attempt.
Fields
page: RepositoryGraphPage<T>Stable bounded page, including its truncation sentinel result.
work: RepositoryGraphReadWorkExact work for all decoded rows, including a removed sentinel.