pub struct RepositoryGraphRelationRow {
pub relation: LogicalRelation,
pub source: GraphEntity,
pub target: Option<GraphEntity>,
pub document_unresolved_reason: Option<DocumentTargetUnresolvedReason>,
}Expand description
One normalized relation with the endpoint entities already hydrated.
Fields
relation: LogicalRelationFully reconstructed normalized relation.
source: GraphEntityExact source entity named by the relation.
target: Option<GraphEntity>Retained resolved or external target, when the relation has one.
document_unresolved_reason: Option<DocumentTargetUnresolvedReason>Closed reason retained only for an unresolved documents relation.