pub enum DatabaseFilesystemSupport {
SupportedLocal,
Unsupported,
Uncertain,
}Expand description
WAL suitability of the selected database filesystem.
Variants
SupportedLocal
The location resolved to an admitted local filesystem.
Unsupported
The location resolved to a known unsupported network or distributed filesystem.
Uncertain
The runtime could not prove an admitted local filesystem.