pub enum DatabaseSchemaCompatibility {
Missing,
Current,
SupportedPredecessor,
Incompatible,
Corrupt,
NotInspected,
}Expand description
Compatibility of the selected database with the current runtime.
Variants
Missing
The database file does not exist yet.
Current
The durable schema matches the current runtime.
SupportedPredecessor
The durable schema is an admitted predecessor with a transactional migration path.
Incompatible
The durable schema or project binding is not admitted by this runtime.
Corrupt
SQLite or its integrity check identified corrupt database state.
NotInspected
Filesystem support could not admit a safe database inspection.