pub fn verify_project_database(path: &Path, project_root: &Path) -> DbResult<()>Expand description
Verify the current project database schema, identity, and full integrity read-only.
Errors
Returns an error when the database is missing, incompatible, corrupt, or belongs to another project root.