pub struct CapturedProjectBinding {
pub project_instance_id: ProjectInstanceId,
pub project_root: String,
}Expand description
Root and project identity captured when one store binding was validated.
Fields
project_instance_id: ProjectInstanceIdStable project identity captured at open or explicit root transition.
project_root: StringNormalized local source root captured with the project identity.