RepositoryNavigationNode

Struct RepositoryNavigationNode 

pub struct RepositoryNavigationNode {
    pub path: String,
    pub kind: NodeKind,
}
One folder or file whose current graph context should enrich navigation.

Fields

path: String

Exact repository-relative path.

kind: NodeKind

Folder or file ownership semantics used by the set query.